'''
Mail configs start
mail_configs['appid']
mail_configs['appkey']
mail_configs['sign_type']
'''
MAIL_CONFIGS = {}
'''
Mail appid
'''
MAIL_CONFIGS['appid'] = 'your_mail_app_id'

'''
Mail appkey
'''
MAIL_CONFIGS['appkey'] = 'your_mail_app_key'

'''
Mail Sign type
md5/sha1/normal
'''
MAIL_CONFIGS['sign_type'] = 'md5'

'''
Mail configs end
'''

'''
Message configs start
message_configs['appid']
message_configs['appkey']
message_configs['sign_type']
'''
MESSAGE_CONFIGS = {}
'''
Message appid
'''
MESSAGE_CONFIGS['appid'] = '10997'

'''
Message appkey
'''
MESSAGE_CONFIGS['appkey'] = '379bc3fdf9c44c81ee5f0a8a372863ea'

'''
Message Sign type
md5/sha1/normal
'''
MESSAGE_CONFIGS['sign_type'] = 'md5'

'''
Message configs end
'''
